@@ -1,16 +1,13 @@
-use std::collections::HashMap;
-
 /*
  * @Author: tzw
  * @Date: 2021-11-02 20:30:11
  * @LastEditors: tzw
- * @LastEditTime: 2021-11-04 00:49:25
+ * @LastEditTime: 2021-11-22 00:50:22
  */
 use actix_web::route;
 use actix_web::*;
 use serde::{Deserialize, Serialize};
 
-use crate::pubsub::DaprTopicSubscription;
 
 
 
@@ -30,35 +27,42 @@ use crate::pubsub::DaprTopicSubscription;
    * @param id Actor Id.
    * @return Void.
    */
- #[get("/dapr/subscribe")]
- pub async fn dapr_subscribe()-> impl Responder {
-    let mut subscriptions:Vec<DaprTopicSubscription> =Vec::new();
-    let dapr_topic_subscription=DaprTopicSubscription {
-      pubsub_name: Some("messagebus".to_string()),
-      topic:Some("topic1".to_string()),
-      route:Some("path1".to_string()),
-      metadata:None
-    };  
-   subscriptions.push(dapr_topic_subscription);
+//  #[get("/dapr/subscribe")]
+//  pub async fn dapr_subscribe()-> impl Responder {
+//     let mut subscriptions:Vec<DaprTopicSubscription> =Vec::new();
+//     let dapr_topic_subscription=DaprTopicSubscription {
+//       pubsub_name: Some("messagebus".to_string()),
+//       topic:Some("topicA".to_string()),
+//       route:Some("consumers".to_string()),
+//       metadata:None
+//     };  
+//    subscriptions.push(dapr_topic_subscription);
   
-   let mut metadata:HashMap<String,String>=HashMap::new();
-   metadata.insert("key".to_string(),"value".to_string());
-   metadata.insert("key1".to_string(),"value1".to_string());
-   let dapr_topic_subscription=DaprTopicSubscription {
-    pubsub_name: Some("messagebus".to_string()),
-    topic:Some("topic2".to_string()),
-    route:Some("path2".to_string()),
-    metadata:Some(metadata)
-  };  
+//    let mut metadata:HashMap<String,String>=HashMap::new();
+//    metadata.insert("partitionKey".to_string(),"value".to_string());
+//    metadata.insert("key1".to_string(),"value1".to_string());
+//    let dapr_topic_subscription=DaprTopicSubscription {
+//     pubsub_name: Some("messagebus".to_string()),
+//     topic:Some("topicB".to_string()),
+//     route:Some("consumers".to_string()),
+//     metadata:None,
+//   };  
 
- subscriptions.push(dapr_topic_subscription);
-  
- return HttpResponse::Ok()
-    .set_header("Access-Control-Allow-Origin", "*")
-    .set_header("Cache-Control", "no-cache")
-    .set_header("Content-Type", "text/json;charset=UTF-8")
-    .body(serde_json::to_string(&subscriptions).unwrap());
-}
+//  subscriptions.push(dapr_topic_subscription);
+// //  let dapr_topic_subscription=DaprTopicSubscription {
+// //   pubsub_name: Some("messagebus".to_string()),
+// //   topic:Some("topicC".to_string()),
+// //   route:Some("/consumers".to_string()),
+// //   metadata:None
+// // };  
+// // subscriptions.push(dapr_topic_subscription);
+ 
+// return HttpResponse::Ok()
+//     .set_header("Access-Control-Allow-Origin", "*")
+//     .set_header("Cache-Control", "no-cache")
+//     .set_header("Content-Type", "text/json;charset=UTF-8")
+//     .body(serde_json::to_string(&subscriptions).unwrap());
+// }
 
   /**
    * Handles API to deactivate an actor.
@@ -146,7 +150,7 @@ pub struct ActorPathDto {
 /// dapr 相关接口注册成为 actix_web 的 service
 pub fn dapr_service_config(cfg: &mut web::ServiceConfig) {
   cfg.service(dapr_config)
-     .service(dapr_subscribe)
+    //  .service(dapr_subscribe)
      .service(deactivate_actor) 
      .service(invoke_actor_reminder)
      .service(invoke_actor_method)
